@@ -1,32 +1,25 @@
-"""
-(*)~---------------------------------------------------------------------------
-Pupil - eye tracking platform
-Copyright (C) 2012-2019 Pupil Labs
-
-Distributed under the terms of the GNU
-Lesser General Public License (LGPL v3.0).
-See COPYING and COPYING.LESSER for license details.
----------------------------------------------------------------------------~(*)
-"""
 import enum
 import logging
 import traceback
 from typing import Dict, NamedTuple, Type
 
-import numpy as np
 import cv2  # Todo: DELETE
-from .geometry.projections import (
-    unproject_edges_to_sphere,
-    project_point_into_image_plane,
-)  # Todo: DELETE
+import numpy as np
 
 from .camera import CameraModel
 from .constants import _EYE_RADIUS_DEFAULT
 from .cpp.pupil_detection_3d import get_edges
 from .cpp.pupil_detection_3d import search_on_sphere as search_on_sphere
+from .eye_model import (
+    SphereCenterEstimates,
+    TwoSphereModel,
+    TwoSphereModelAbstract,
+    TwoSphereModelAsync,
+)
 from .geometry.primitives import Circle, Ellipse, Sphere
-from .geometry.projections import (
+from .geometry.projections import (  # Todo: DELETE
     project_circle_into_image_plane,
+    project_point_into_image_plane,
     project_sphere_into_image_plane,
 )
 from .geometry.utilities import cart2sph, sph2cart
@@ -36,12 +29,6 @@ from .observation import (
     BufferedObservationStorage,
     Observation,
 )
-from .eye_model import (
-    SphereCenterEstimates,
-    TwoSphereModelAbstract,
-    TwoSphereModel,
-    TwoSphereModelAsync,
-)
 
 logger = logging.getLogger(__name__)
 
@@ -99,7 +86,7 @@ def sigmoid(x, baseline=0.1, amplitude=500.0, center=0.99, width=0.02):
     return baseline + amplitude * 1.0 / (1.0 + np.exp(-(x - center) / width))
 
 
-class Detector3D(object):
+class Detector3D:
     def __init__(
         self,
         camera: CameraModel,
@@ -564,7 +551,8 @@ class Detector3D(object):
         result["ellipse"] = ellipse2dict(projected_pupil_circle)
         result["location"] = result["ellipse"]["center"]  # pupil center in pixels
 
-        # projected_pupil_circle is an OpenCV ellipse, i.e. major_radius is major diameter
+        # projected_pupil_circle is an OpenCV ellipse,
+        # i.e. major_radius is major diameter
         result["diameter"] = projected_pupil_circle.major_radius
 
         result["confidence"] = observation.confidence
@@ -589,7 +577,7 @@ class Detector3D(object):
             result["theta"] = theta
             result["phi"] = phi
 
-            is_phi_in_range = -80 <= np.rad2deg(phi) + 90.0 <= 80
+            is_phi_in_range = -90 <= np.rad2deg(phi) + 90.0 <= 90
             is_theta_in_range = -80 <= np.rad2deg(theta) - 90.0 <= 80
             if not is_phi_in_range or not is_theta_in_range:
                 result["model_confidence"] = model_confidence_out_of_range
@@ -598,9 +586,9 @@ class Detector3D(object):
             result["phi"] = 0.0
             result["model_confidence"] = model_confidence_phi_theta_nan
 
-        is_center_x_in_range = -10 <= prediction_corrected.sphere_center[0] <= 10
+        is_center_x_in_range = -15 <= prediction_corrected.sphere_center[0] <= 15
         is_center_y_in_range = -10 <= prediction_corrected.sphere_center[1] <= 10
-        is_center_z_in_range = 20 <= prediction_corrected.sphere_center[2] <= 75
+        is_center_z_in_range = 15 <= prediction_corrected.sphere_center[2] <= 75
         is_diameter_in_range = 1.0 <= result["diameter_3d"] <= 9.0
         parameters_in_range = (
             is_center_x_in_range,
