@@ -1,17 +1,7 @@
-"""
-(*)~---------------------------------------------------------------------------
-Pupil - eye tracking platform
-Copyright (C) 2012-2019 Pupil Labs
-
-Distributed under the terms of the GNU
-Lesser General Public License (LGPL v3.0).
-See COPYING and COPYING.LESSER for license details.
----------------------------------------------------------------------------~(*)
-"""
 from abc import abstractmethod, abstractproperty
 from collections import deque
 from math import floor
-from typing import Sequence, Optional
+from typing import Optional, Sequence
 
 import numpy as np
 from sortedcontainers import SortedList
@@ -22,7 +12,7 @@ from .geometry.primitives import Ellipse, Line
 from .geometry.projections import project_line_into_image_plane, unproject_ellipse
 
 
-class Observation(object):
+class Observation:
     def __init__(
         self, ellipse: Ellipse, confidence: float, timestamp: float, focal_length: float
     ):
@@ -48,11 +38,7 @@ class Observation(object):
         self.circle_3d_pair = circle_3d_pair
 
         self.gaze_3d_pair = [
-            Line(
-                circle_3d_pair[i].center,
-                circle_3d_pair[i].center + circle_3d_pair[i].normal,
-            )
-            for i in [0, 1]
+            Line(circle_3d_pair[i].center, circle_3d_pair[i].normal) for i in [0, 1]
         ]
         self.gaze_2d = project_line_into_image_plane(self.gaze_3d_pair[0], focal_length)
         self.gaze_2d_line = np.array([*self.gaze_2d.origin, *self.gaze_2d.direction])
